@@ -72,7 +72,7 @@ def namespace_to_dict(namespace: 'Namespace') -> Dict[str, Any]:
     return namespace.clone().as_dict()
 
 
-def dict_to_namespace(cfg_dict: Dict[str, Any]) -> 'Namespace':
+def dict_to_namespace(cfg_dict: Union[Dict[str, Any], 'Namespace']) -> 'Namespace':
     """Converts a nested dictionary into a nested namespace."""
     cfg_dict = deepcopy(cfg_dict)
     def expand_dict(cfg):
@@ -169,7 +169,10 @@ class Namespace(ArgparseNamespace):
         leaf_key, parent_ns, parent_key = self._parse_key(key)
         if parent_ns is None:
             parent_ns = self._create_nested_namespace(parent_key)
-        setattr(parent_ns, leaf_key, item)
+        if isinstance(parent_ns, dict):
+            parent_ns[leaf_key] = item
+        else:
+            setattr(parent_ns, leaf_key, item)
 
     def __getitem__(self, key: str) -> Any:
         """Gets an item from a possibly nested namespace."""
@@ -191,6 +194,10 @@ class Namespace(ArgparseNamespace):
             return False
         return leaf_key in parent_ns.__dict__
 
+    def __bool__(self) -> bool:
+        """Returns False if namespace is empty, otherwise True."""
+        return bool(self.__dict__)
+
     def as_dict(self) -> Dict[str, Any]:
         """Converts the nested namespaces into nested dictionaries."""
         dic = {}
@@ -257,7 +264,7 @@ class Namespace(ArgparseNamespace):
 
         Args:
             value: A namespace to update multiple values or other type to set in a single key.
-            key: Branch key where to set the value. Required if value is not namepace.
+            key: Branch key where to set the value. Required if value is not namespace.
             only_unset: Whether to only set the value if not set in namespace.
         """
         if not isinstance(value, Namespace):
@@ -289,13 +296,6 @@ class Namespace(ArgparseNamespace):
         return parent_ns.__dict__.pop(leaf_key, default)
 
 
-_empty_namespace = Namespace()
-
-
-def is_empty_namespace(ns):
-    return ns == _empty_namespace
-
-
 # Temporal to provide backward compatibility in pytorch-lightning
 import yaml
 yaml.SafeDumper.add_representer(Namespace, lambda d, x: d.represent_mapping('tag:yaml.org,2002:map', x.as_dict()))
